package cn.iocoder.yudao.module.system.enums.sms;

import cn.hutool.core.util.ArrayUtil;
import cn.iocoder.yudao.framework.common.util.json.core.IntArrayValuable;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;

/**
 * 用户短信验证码发送场景的枚举
 *
 * @author 捷道源码
 */
@Getter
@AllArgsConstructor
public enum SmsSceneEnum implements IntArrayValuable {

    MEMBER_REG(0, "user-sms-reg", "会员用户 - 手机号注册"),
    MEMBER_LOGIN(1, "user-sms-login", "会员用户 - 手机号登陆"),
    MEMBER_UPDATE_MOBILE(2, "user-sms-update-mobile", "会员用户 - 解绑手机"),
    MEMBER_FORGET_PASSWORD(3, "user-sms-reset-password", "会员用户 - 忘记密码"),
    TRANSFER_CONTROL_GOODS(4, "transfer-control-goods", "订单 - 控货权转移"),
    DELIVERY_VERIFICATION_SMS(5, "delivery-verification-sms", "订单 - 放货验证短信"),


    NOTIFICATION_SUCCESS_DELIVERY(6, "notification-successful-delivery", "订单 - 放货成功通知"),
    NOTIFICATION_SUCCESS_CANCEL_DELIVERY(7, "notification-successful-cancel-delivery", "订单 - 取消放货通知"),
    NOTIFICATION_SUCCESS_SEASONING_CONDIMENTS(8, "notification-successful-seasoning-condiments", "订单 - 调货通知"),

    MEMBER_REDEEM_REWARD(9, "user-sms-redeem-reward", "会员用户 - 兑换礼品"),


    SHIPMENT_ARRIVALS(20, "shipment-arrivals", "出货 - 到港通知(多订单)"),
    SHIPMENT_CUSTOMS_CLEARANCES(21, "shipment-customs-clearances", "出货 - 清关通知(多订单)"),
    SHIPMENT_CABINETS(22, "shipment-cabinets", "出货 - 装柜通知(多订单)"),
    SHIPMENT_ARRIVAL(23, "shipment-arrival", "出货 - 到港通知"),
    SHIPMENT_CUSTOMS_CLEARANCE(24, "shipment-customs-clearance", "出货 - 清关通知"),
    SHIPMENT_CABINET(25, "shipment-cabinet", "出货 - 装柜通知"),
    SHIPMENT_CLOSE_CONTAINER(26, "shipment-close-container", "出货 - 封柜反审"),

    WAREHOUSE_IN_CONTROL(50, "warehouse-in-control", "入仓控货通知"),
    WAREHOUSE_IN(51, "warehouse-in", "入仓通知"),
    WAREHOUSE_IN_APPEND(52, "warehouse-in-append", "追加通知"),
    WAREHOUSE_IN_CONTROL_COLLECT_OF_GOODS(53, "warehouse-in-control-collect-of-goods", "入仓-控货代收货款"),
    WAREHOUSE_IN_COLLECT_OF_GOODS(54, "warehouse-in-collect-of-goods", "入仓-非控货代收货款"),


    /** 空运新增模板 **/

    AIR_WAREHOUSE_IN_CONTROL(55, "air-warehouse-in-control", "入仓控货通知"),

    AIR_WAREHOUSE_IN(56, "air-warehouse-in", "入仓通知"),

    AIR_SHIPMENT_ARRIVAL(57, "air-shipment-arrival", "出货 - 到港通知"),
    AIR_SHIPMENT_ARRIVALS(58, "air-shipment-arrivals", "出货 - 到港通知(多订单)"),
    AIR_SHIPMENT_CUSTOMS_CLEARANCE(59, "air-shipment-customs-clearance", "出货 - 清关通知"),
    AIR_SHIPMENT_CUSTOMS_CLEARANCES(60, "air-shipment-customs-clearances", "出货 - 清关通知(多订单)"),

    AIR_SHIPMENT_WAREHOUSE(61, "air-shipment-warehouse", "出货 - 出仓通知"),
    AIR_SHIPMENT_WAREHOUSES(62, "air-shipment-warehouses", "出货 - 出仓通知(多订单)"),

        AIR_WAREHOUSE_IN_COLLECT_OF_GOODS(63, "air-warehouse-in-collect-of-goods", "入仓-非控货代收货款"),
    ;

    // 如果未来希望管理后台支持手机验证码登陆，可以通过添加 ADMIN_MEMBER_LOGIN 枚举

    public static final int[] ARRAYS = Arrays.stream(values()).mapToInt(SmsSceneEnum::getScene).toArray();

    /**
     * 验证场景的编号
     */
    private final Integer scene;
    /**
     * 模版编码
     */
    private final String templateCode;
    /**
     * 描述
     */
    private final String description;

    @Override
    public int[] array() {
        return ARRAYS;
    }

    public static SmsSceneEnum getCodeByScene(Integer scene) {
        return ArrayUtil.firstMatch(sceneEnum -> sceneEnum.getScene().equals(scene),
                values());
    }

}
